@@ -1,32 +1,24 @@
-from typing import Any, Dict, Union
+from typing import Any, Dict
 
 import httpx
 
 from ...client import AuthenticatedClient
-from ...models.jiraffe_api_v1_sync_create_format import JiraffeApiV1SyncCreateFormat
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, JiraffeApiV1SyncCreateFormat] = UNSET,
 ) -> Dict[str, Any]:
-    url = "/jiraffe/api/v1/sync"
+    url = "{}/jiraffe/api/v1/sync".format(
+        client.base_url,
+    )
 
-    json_format_: Union[Unset, None, str] = UNSET
-    if not isinstance(format_, Unset):
-
-        json_format_ = JiraffeApiV1SyncCreateFormat(format_).value if format_ else None
-
-    params: Dict[str, Any] = {
-        "format": json_format_,
-    }
-    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+    headers: Dict[str, Any] = client.get_headers()
 
     return {
         "url": url,
-        "params": params,
+        "headers": headers,
     }
 
 
@@ -42,14 +34,15 @@ def _build_response(*, response: httpx.Response) -> Response[Any]:
 def sync_detailed(
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, JiraffeApiV1SyncCreateFormat] = UNSET,
 ) -> Response[Any]:
     kwargs = _get_kwargs(
         client=client,
-        format_=format_,
     )
 
-    response = client.get_session().post(
+    response = httpx.post(
+        verify=client.verify_ssl,
+        auth=client.auth,
+        timeout=client.timeout,
         **kwargs,
     )
     response.raise_for_status()
@@ -60,11 +53,9 @@ def sync_detailed(
 async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, JiraffeApiV1SyncCreateFormat] = UNSET,
 ) -> Response[Any]:
     kwargs = _get_kwargs(
         client=client,
-        format_=format_,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
