@@ -1,35 +1,26 @@
-from typing import Any, Dict, Union
+from typing import Any, Dict
 
 import httpx
 
 from ...client import AuthenticatedClient
-from ...models.osim_api_v1_workflows_adjust_create_format import OsimApiV1WorkflowsAdjustCreateFormat
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
     id: str,
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, OsimApiV1WorkflowsAdjustCreateFormat] = UNSET,
 ) -> Dict[str, Any]:
-    url = "/osim/api/v1/workflows/{id}/adjust".format(
+    url = "{}/osim/api/v1/workflows/{id}/adjust".format(
+        client.base_url,
         id=id,
     )
 
-    json_format_: Union[Unset, None, str] = UNSET
-    if not isinstance(format_, Unset):
-
-        json_format_ = OsimApiV1WorkflowsAdjustCreateFormat(format_).value if format_ else None
-
-    params: Dict[str, Any] = {
-        "format": json_format_,
-    }
-    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+    headers: Dict[str, Any] = client.get_headers()
 
     return {
         "url": url,
-        "params": params,
+        "headers": headers,
     }
 
 
@@ -46,15 +37,16 @@ def sync_detailed(
     id: str,
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, OsimApiV1WorkflowsAdjustCreateFormat] = UNSET,
 ) -> Response[Any]:
     kwargs = _get_kwargs(
         id=id,
         client=client,
-        format_=format_,
     )
 
-    response = client.get_session().post(
+    response = httpx.post(
+        verify=client.verify_ssl,
+        auth=client.auth,
+        timeout=client.timeout,
         **kwargs,
     )
     response.raise_for_status()
@@ -66,12 +58,10 @@ async def asyncio_detailed(
     id: str,
     *,
     client: AuthenticatedClient,
-    format_: Union[Unset, None, OsimApiV1WorkflowsAdjustCreateFormat] = UNSET,
 ) -> Response[Any]:
     kwargs = _get_kwargs(
         id=id,
         client=client,
-        format_=format_,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
